/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is MPEG4IP.
 * 
 * The Initial Developer of the Original Code is Cisco Systems Inc.
 * Portions created by Cisco Systems Inc. are
 * Copyright (C) Cisco Systems Inc. 2005.  All Rights Reserved.
 * 
 * Contributor(s): 
 *              Bill May        wmay@cisco.com
 */
#ifndef __TEXT_PLUGIN_H__
#define __TEXT_PLUGIN_H__

#include <mpeg4ip.h>

#define TEXT_DISPLAY_TYPE_PLAIN  0
#define TEXT_DISPLAY_TYPE_HREF   1

typedef struct plain_display_structure_t {
  const char *display_string;
} plain_display_structure_t;

typedef struct href_display_structure_t {
  const char *url;
  const char *target_element;
  const char *embed_element;
  bool send_click_location;
  bool auto_dispatch;
} href_display_structure_t;

#endif
